@@ -127,7 +127,16 @@ def bruteforce(minLength=1, maxLength=4, charSet=string.ascii_letters+string.dig
 
 
 def bruteforceList(stringList, noOfThreads=1, callback=print, debug=False):
-    
+    """Given a list iterates that and calls callback for each item
+
+    Args:
+        stringList (list): The list of strings
+        noOfThreads (int, optional): Number of threads to use. Defaults to 1.
+        callback (function, optional): Callback function. Defaults to print.
+        debug (bool, optional): Set to True if all chars needed to be printed. Defaults to False
+    Returns:
+        str or None: Returns the String that was used for solving by callback
+    """
     def start(currList):
         for i in currList:
             if stop:
@@ -187,6 +196,16 @@ def bruteforceList(stringList, noOfThreads=1, callback=print, debug=False):
 
 
 def bruteforceFile(file, noOfThreads=1, callback=print, debug=False):
+    """Given a file, iterates that and calls callback for each item
+
+    Args:
+        file (str): Location of file
+        noOfThreads (int, optional): Number of threads to use. Defaults to 1.
+        callback (function, optional): Callback function. Defaults to print.
+        debug (bool, optional): Set to True if all chars needed to be printed. Defaults to False
+    Returns:
+        str or None: Returns the String that was used for solving by callback
+    """
     from webXtools.helper import splitFile
     stringList = splitFile(file)
     return(bruteforceList(stringList, noOfThreads, callback, debug))
